@@ -33,7 +33,8 @@ class NewsDataIo(BaseProvider):
 	
 	def news(self, q=None, 
 						categories=[],
-						countries=[], 
+						countries=[],
+						domains=[],
 						language=[], 
 						page=0):
 		url = 'https://newsdata.io/api/1/news'
@@ -41,14 +42,16 @@ class NewsDataIo(BaseProvider):
 		keyword = q
 		if keyword == '':
 			keyword = None
-		categories = None if len(categories) == 0 else categories[0]
-		language_str = None if len(language) == 0 else language[0]
-		countries_str = None if len(countries) == 0 else countries[0]
+		categories = self.newsfeed.array2params(categories)
+		language_str = self.newsfeed.array2params(language)
+		countries_str = self.newsfeed.array2params(countries)
+		domain_str = self.newsfeed.array2param(domains)
 		today = curDateString()
 		p = {
 			'apikey':self.appkey,
 			'country':countries_str,
-			'categories':categories,
+			'category':categories,
+			'domain':domain_str,
 			'language':language_str,
 			'page':page,
 			'q':keyword
@@ -57,26 +60,63 @@ class NewsDataIo(BaseProvider):
 		x = hc.get(url, params=p)
 		return x
 
-	def topstory(self, q=None, categories=[],
-						countries=[], language=[], page=0):
-		url = 'https://newsapi.org/v2/top-headlines'
+	def sources_result_mapping(self):
+		return {
+			'sources':'results'
+		}
+
+	def source_mapping(self):
+		return {
+			'categories':'category',
+			'link':'url',
+			'countries':'country'
+		}
+
+	def sources(self, countries=[], categories=[], language=[]):
+		url = 'https://newsapi.org/v2/sources'
+		categories = self.newsfeed.array2param(categories)
+		language_str = self.newsfeed.array2param(language)
+		countries_str = self.newsfeed.array2param(countries)
+		p = {
+			'apiKey':self.appkey,
+			'category':categories, 
+			'country':countries_str,
+			'language':language
+		}
 		hc = Http_Client()
+		print('url=', url, 'params=', p)
+		x = hc.get(url, params=p)
+		return x
+		
+	def topstory(self, q=None, categories=[],
+						countries=[], 
+						domains=[],
+						language=[], 
+						from_date=None,
+						to_date=None,
+						page=0):
+		url = 'https://newsdata.io/api/1/archive'
 		keyword = q
 		if keyword == '':
 			keyword = None
 		categories = self.newsfeed.array2param(categories)
 		language_str = self.newsfeed.array2param(language)
 		countries_str = self.newsfeed.array2param(countries)
+		domains_str = self.newsfeed.array2param(domains)
 		today = curDateString()
 		p = {
-			'apiKey':self.appkey,
+			'apikey':self.appkey,
 			'category':categories, 
 			'country':countries_str,
-			'pageSize':100,
+			'language':language_str,
+			'domains':domains_str,
+			'from_date':from_date,
+			'to_date':to_date,
 			'page':page,
 			'q':keyword
 		}
 		print('url=', url, 'params=', p)
+		hc = Http_Client()
 		x = hc.get(url, params=p)
 		return x
 
